/*
 * CPUGovernorService.cpp
 *
 *  Created on: Feb 1, 2021
 *      Author: emanoil
 *
 * hardwarecontrol Copyright (C) 2021 trinity desktop development team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#include "CPUGovernorService.h"

CPUGovernorService::CPUGovernorService(TQT_DBusConnection &conn)
: DeviceServiceBase(conn)
{
    // TODO Auto-generated constructor stub

}

CPUGovernorService::~CPUGovernorService()
{
    // TODO Auto-generated destructor stub
}

/*!
 * Implement virtual methods
 *
 */
bool CPUGovernorService::CanSetCPUGovernor(TQ_INT32 cpu, bool& value, TQT_DBusError& error) {
    // do something
    TQString dev = TQString("/sys/devices/system/cpu/cpu%1/cpufreq/scaling_governor").arg(cpu);
    if ((cpu>-1)) {
        value = canSetDeviceValue(dev, error);
    } else {
        error = TQT_DBusError::stdInvalidArgs(TQString ("Invalid argument cpu: %1, governor: %2").arg(cpu).arg(dev));
    }
    if (error.isValid()) {
        tqDebug(error.message().local8Bit());
        return false;
    }
    return true;
}

bool CPUGovernorService::SetCPUGovernor(TQ_INT32 cpu, const TQString& governor, bool& value, TQT_DBusError& error) {

    TQString dev = TQString("/sys/devices/system/cpu/cpu%1/cpufreq/scaling_governor").arg(cpu);
    if ((cpu>-1) && !governor.isEmpty()) {
        value = setDeviceValue(dev, governor, error);
    } else {
        error = TQT_DBusError::stdInvalidArgs(TQString ("Invalid argument cpu: %1, governor: %2").arg(cpu).arg(governor));
    }
    if (error.isValid()) {
        tqDebug(error.message().local8Bit());
        return false;
    }
    return true;
}

void CPUGovernorService::handleMethodReply(const TQT_DBusMessage& reply) {
    m_connection->send(reply);
}

