/*
 * HardwareControl.h
 *
 *  Created on: Feb 2, 2021
 *      Author: emanoil
 *
 * hardwarecontrol Copyright (C) 2021 trinity desktop development team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef HARDWARECONTROL_H_
#define HARDWARECONTROL_H_

#include <tqapplication.h>

#include "hardwarecontrolService.h"

class HardwareControl: public TQApplication
{
    TQ_OBJECT

public:
    HardwareControl(int &argc, char **argv, bool GUIenabled, bool SMenabled);
    virtual ~HardwareControl();

private:
    /*!
     * This function initialise the connection to the D-Bus daemon.
     * \return boolean with the result of the operation
     * \retval true if successful initialised D-Bus connection
     * \retval false if unsuccessful
     */
    bool initDBUS();
    //! to close the connection to D-Bus
    void close();

    RootNodeService *rootService;
    OrgNodeService   *orgService;
    TrinityDesktopNodeService *trinitydesktopService;
    HardwareControlNodeService *hardwarecontrolService;
    int retryCount;
    TQString serviceName;
    TQT_DBusConnection m_connection;

private slots:
    /*!
     * This function does a reconnect to D-Bus.
     * \return void
     */
    void slotReconnect();
    /*!
     * This function is to process D-Bus signals.
     * \return void
     */
    void slotDbusSignal(const TQT_DBusMessage&);
    /*!
     * This function is to check D-Bus connection.
     * and if the name is the unique name prepare the receivers
     * If the name is not the unique name it mans the service
     * is already running or unique name can not be obtained from
     * DBus. In this latter case the application will terminate.
     *
     * \return void
     */
    void slotConnectionCheck();

};


#endif /* HARDWARECONTROL_H_ */
