/*
 *
 *  HardwareControl DBus Service implementation
 *
 *  Copyright (C) 2020  Emanoil Kotsev <deloptes@gmail.com>
 *
 *
 *  This file is part of tdecore/tdehw.
 *
 *  hardwarecontrol is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  hardwarecontrol is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with tdelibs; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
#ifndef HARDWARECONTROLSERVICE_H
#define HARDWARECONTROLSERVICE_H

#include <tqmap.h>
#include <tqdbusconnection.h>

#include "interfaces/hardwarecontrolNode.h"
#include "interfaces/dbusbaseNode.h"

/**
 * RootNodeService
 *  Service: -
 *  Path   : /
 *  Children: org
 */
class RootNodeService : public DBusBaseNode
{
public:
    RootNodeService(TQT_DBusConnection&);
    ~RootNodeService();
protected:
    virtual TQT_DBusObjectBase* createInterface(const TQString&);
private:
    TQMap<TQString, TQT_DBusObjectBase*> m_interfaces;
    TQT_DBusConnection m_connection;
};

/**
 * OrgNodeService
 *  Service: -
 *  Path   : /org
 *  Children: trinitydesktop
 */
class OrgNodeService : public DBusBaseNode
{
public:
    OrgNodeService(TQT_DBusConnection&);
    ~OrgNodeService();
protected:
    virtual TQT_DBusObjectBase* createInterface(const TQString&);
private:
    TQMap<TQString, TQT_DBusObjectBase*> m_interfaces;
    TQT_DBusConnection m_connection;
};

/**
 * TrinityDesktopNodeService
 *  Service: -
 *  Path   : /org/trinitydesktop
 *  Children: hardwarecontrol
 */
class TrinityDesktopNodeService : public DBusBaseNode
{
public:
    TrinityDesktopNodeService(TQT_DBusConnection&);
    ~TrinityDesktopNodeService();
protected:
    virtual TQT_DBusObjectBase* createInterface(const TQString&);
private:
    TQMap<TQString, TQT_DBusObjectBase*> m_interfaces;
    TQT_DBusConnection m_connection;
};

/*
 * HardwareControlNodeService
 *  Service: org.freedesktop.DBus.Introspectable
 *  Service: org.freedesktop.DBus.Properties
 *  Service: org.trinitydesktop.hardwarecontrol.Brightness
 *  Service: org.trinitydesktop.hardwarecontrol.CPUGovernor
 *  Service: org.trinitydesktop.hardwarecontrol.InputEvents
 *  Service: org.trinitydesktop.hardwarecontrol.Power
 *  Path   : /org/trinitydesktop/hardwarecontrol
 *  Children: -
 */
class HardwareControlNodeService : public org::trinitydesktop::hardwarecontrolNode
{
public:
    HardwareControlNodeService(TQT_DBusConnection&);
    ~HardwareControlNodeService();

protected:
    virtual TQT_DBusObjectBase* createInterface(const TQString&);

private:
    TQMap<TQString, TQT_DBusObjectBase*> m_interfaces;
    TQT_DBusConnection m_connection;
};


#endif // HARDWARECONTROLSERVICE_H
